;; Generated package description from xref-union.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "xref-union" "0.2.0.0.20260219.213038" "Combine multiple Xref backends" '((emacs "25.1")) :commit "140bdf53e1c1aca1c33a38e10aa6c00c4457eadb" :authors '(("Philip Kaludercic" . "philipk@posteo.net")) :maintainer '("Philip Kaludercic" . "philipk@posteo.net") :url "https://codeberg.org/pkal/xref-union.el")
